@@ -10,7 +10,7 @@ from rich.progress import Progress, track
 
 def get_process(client: ArkindexClient, process_id: UUID) -> dict:
     try:
-        return client.request("RetrieveDataImport", id=process_id)
+        return client.request("RetrieveProcess", id=process_id)
     except ErrorResponse as e:
         if e.status_code == 404:
             raise ValueError(f"Process {process_id} not found.") from e
