@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from arkindex_cli.commands.upload.alto import add_alto_parser
 from arkindex_cli.commands.upload.iiif import add_iiif_parser
 from arkindex_cli.commands.upload.minio_client import add_minio_client_parser
 from arkindex_cli.commands.upload.page_xml_import import add_pagexml_import_parser
@@ -14,6 +15,7 @@ def add_upload_parser(subcommands) -> None:
     add_iiif_parser(subparsers)
     add_minio_client_parser(subparsers)
     add_pagexml_import_parser(subparsers)
+    add_alto_parser(subparsers)
 
     def subcommand_required(*args, **kwargs):
         upload_parser.error("A subcommand is required.")
