@@ -61,7 +61,7 @@ def add_iiif_parser(subcommands):
         "--group-folder-type",
         help=(
             "Type for sub-folders containing grouped IIIF images. "
-            "This parameter requires prefix delimiter to be defined."
+            "This parameter requires prefix delimiter to be defined or keep-hierachy to be set."
         ),
     )
     group = iiif_parser.add_mutually_exclusive_group()
@@ -114,7 +114,8 @@ def run(
     """
     Create elements in a corpus from a list of IIIF paths.
     A single folder will be created at the root of the corpus, with optional name and type.
-    Sub-folders could be created to group images by prefix if .
+    Sub-folders are created to group images by prefix if either keep_hierarchy is set or a
+    group_prefix_delimiter is defined.
     """
 
     with Progress(transient=True) as progress:
